#ifndef DACC_FCPP_HH
#define DACC_FCPP_HH

#ifndef __CINT__
#include "framecpp/Types.hh"
#else
namespace FrameCPP {
  class FrameH;
  class FrAdcData;
  class FrDetector;
  class FrProcData;
  class FrRawData;
  class FrSimData;
  class FrStatData;
  class FrVect;

  namespace Common {
    class FrStatData;
  }
}
#endif  // !def(__CINT__)

#ifndef LDAS_VERSION_NUMBER
#define LDAS_VERSION_NUMBER 200000
#endif

#if !defined(__CINT__) && (LDAS_VERSION_NUMBER > 119010)
#define FCPP_SHARED_PTRS 1
  #if LDAS_VERSION_NUMBER < 200000
    //-------------------------------------------------------------------
    // FrameCPP has complex logic to determine the "best" way to support
    //   memory management
    //-------------------------------------------------------------------
    #include "general/SharedPtr.hh"
    #define FRAMECPP_PTR(a,b) typedef General::SharedPtr<FrameCPP::a> b
  #elif ( FRAMECPP_USES_LDAS_TOOLS_SHARED_PTR )
    //-------------------------------------------------------------------
    // After version 2.0.0, the version number is no longer being supplied
    //-------------------------------------------------------------------
    #include "ldastoolsal/SharedPtr.hh"
    #define FRAMECPP_PTR(a,b) typedef LDASTools::AL::SharedPtr<FrameCPP::a> b;
  #else
    //-------------------------------------------------------------------
    // As of version 2.16.0, FrameCPP uses the boost library for
    // memory management
    //-------------------------------------------------------------------
    #include "boost/shared_ptr.hpp"
    #define FRAMECPP_PTR(a,b) typedef boost::shared_ptr<FrameCPP::a> b;
  #endif
#else
  #define FRAMECPP_PTR(a,b) typedef FrameCPP::a * b;
#endif

FRAMECPP_PTR(FrameH,frameh_pointer);
FRAMECPP_PTR(FrDetector,frdetector_pointer);
FRAMECPP_PTR(FrRawData,frrawdata_pointer);
FRAMECPP_PTR(FrAdcData,fradcdata_pointer);
FRAMECPP_PTR(FrProcData,frprocdata_pointer);
FRAMECPP_PTR(FrSimData,frsimdata_pointer);
FRAMECPP_PTR(Common::FrStatData,frstatdata_pointer);
FRAMECPP_PTR(FrVect,frvect_pointer);

#undef FRAMECPP_PTR

#endif // !defined(DACC_FCPP_HH)
